# `oasr help`

*Showing help*
![oasr help](../.images/help.png)

Show help for any command.

```bash
oasr help
oasr help list
oasr help adapter
oasr help profile
```

## Examples

When you ask for a specific command, `oasr help` includes quick examples:

```bash
oasr help exec
oasr help registry
```
